==> haskell-th-env-0.1.1-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-9OK3gUHL83bHIRJ4lR6BE6
key:                  th-env-0.1.1-9OK3gUHL83bHIRJ4lR6BE6
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  fad610394870f3e4f292558ca4f614c5
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-9OK3gUHL83bHIRJ4lR6BE6
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    th-compat-0.1.5-DGDHQ3zg5lpAWsPNoCEdRG

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-env-0.1.1-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-th-env.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 th-env
version:              0.1.1
visibility:           public
id:                   th-env-0.1.1-HorhgyqTQBuKwSbBNYMkKG
key:                  th-env-0.1.1-HorhgyqTQBuKwSbBNYMkKG
license:              BSD-3-Clause
maintainer:           dima@dzhus.org
author:               Dmitry Dzhus
homepage:             https://github.com/dzhus/th-env#readme
synopsis:
    Template Haskell splices that expand to an environment variable

description:
    TH splices that expand to an environment variable value. Can be used to embed build-time parameters in your application.

category:             Template Haskell
abi:                  9d8d0f0d50527743eeafaee02ad29332
exposed:              True
exposed-modules:      Language.Haskell.TH.Env
hidden-modules:       Paths_th_env
import-dirs:          /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/th-env-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-th-env
hs-libraries:         HSth-env-0.1.1-HorhgyqTQBuKwSbBNYMkKG
depends:
    base-4.17.2.1 template-haskell-2.19.0.0
    th-compat-0.1.6-4oe2nIahlu72vkc42MDQZC

haddock-interfaces:   /usr/share/doc/haskell-th-env/html/th-env.haddock
haddock-html:         /usr/share/doc/haskell-th-env/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
